==> pretty_yarrrml2rml-0.5.dev1626691516.tar.gz: pretty_yarrrml2rml-0.5.dev1626691516/pretty_yarrrml2rml/constants.py <==



##############################################################################
#############################   RML CONSTANTS  ###############################
##############################################################################

RML_URI = 'http://semweb.mmlab.be/ns/rml#'
R2RML_URI = 'http://www.w3.org/ns/r2rml#'
RDF_URI = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'
D2RQ_URI = 'http://www.wiwiss.fu-berlin.de/suhl/bizer/D2RQ/0.1#'
QL_URI = 'http://semweb.mmlab.be/ns/ql#'
EXAMPLE_URI = 'http://example.com/ns#'
RDF_TYPE = 'rdf:type'

RML_PREFIX = '@prefix'
RML_BASE = '@base'
RML_TRIPLES_MAP = 'rr:TriplesMap'


RML_LOGICAL_SOURCE_CLASS = 'rml:LogicalSource'
RML_LOGICAL_SOURCE = 'rml:logicalSource'
RML_SOURCE = 'rml:source'
RML_REFERENCE_FORMULATION = 'rml:referenceFormulation'
RML_ITERATOR = 'rml:iterator'
RML_REFERENCE = 'rml:reference'




R2RML_TEMPLATE = 'rr:template'
R2RML_CONSTANT = 'rr:constant'
R2RML_SUBJECT_PROPERTY = 'rr:subjectMap'
R2RML_SUBJECT_CLASS = 'rr:SubjectMap'
R2RML_SQL_VERSION = 'rr:sqlVersion'
R2RML_SQL_QUERY = 'rr:sqlQuery'
R2RML_PREDICATE_OBJECT_MAP = 'rr:predicateObjectMap'
R2RML_PREDICATE_OBJECT_MAP_CLASS = 'rr:PredicateObjectMap'
R2RML_SHORTCUT_PREDICATE = 'rr:predicate'
R2RML_PREDICATE = 'rr:predicateMap'
R2RML_PREDICATE_CLASS = 'rr:PredicateMap'
R2RML_SHORTCUT_OBJECT = 'rr:object'
R2RML_OBJECT = 'rr:objectMap'
R2RML_OBJECT_CLASS = 'rr:ObjectMap'
R2RML_DATATYPE = 'rr:datatype'
R2RML_TERMTYPE = 'rr:termType'
R2RML_LANGUAGE = 'rr:language'
R2RML_IRI = 'rr:IRI'
R2RML_REFOBJECT_CLASS = 'rr:RefObjectMap'
R2RML_PARENT_TRIPLESMAP = 'rr:parentTriplesMap'
R2RML_JOIN_CONITION = 'rr:joinCondition'
R2RML_CHILD = 'rr:child'
R2RML_PARENT = 'rr:parent'

##############################################################################
#############################   D2RQ CONSTANTS  ###########################
##############################################################################
D2RQ_DATABASE_CLASS = 'd2rq:Database'
D2RQ_DSN = 'd2rq:jdbcDSN'
D2RQ_DRIVER = 'd2rq:jdbcDriver'
D2RQ_USER = 'd2rq:username'
D2RQ_PASS = 'd2rq:password'


##############################################################################
#############################   YARRRML CONSTANTS  ###########################
##############################################################################

YARRRML_PREFIXES = 'prefixes'
YARRRML_MAPPINGS = 'mappings'

YARRRML_SOURCES = 'sources'
YARRRML_SOURCE = 'source'
YARRRML_ACCESS = 'access'
YARRRML_QUERY = 'query'
YARRRML_REFERENCE_FORMULATION = 'referenceFormulation'
YARRRML_ITERATOR = 'iterator'
YARRRML_CREDENTIALS = 'credentials'
YARRRML_TYPE = 'type'
YARRRML_USERNAME = 'username'
YARRRML_PASSWORD = 'password'

YARRRML_SHORTCUT_SUBJECTS = 's'
YARRRML_SUBJECT = 'subject'
YARRRML_SUBJECTS = 'subjects'


YARRRML_PREDICATEOBJECT = 'predicateobjects'
YARRRML_SHORTCUT_PREDICATEOBJECT = 'po'

YARRRML_PREDICATES = 'predicates'
YARRRML_SHORTCUT_PREDICATES = 'p'
YARRRML_OBJECT = 'objects'
YARRRML_SHORTCUT_OBJECT = 'o'
YARRRML_VALUE = 'value'
YARRRML_MAPPING = 'mapping'
YARRRML_DATATYPE = 'datatype'
YARRRML_LANGUAGE = 'language'

YARRRML_CONDITION = 'condition'
YARRRML_PARAMETERS = 'parameters'

YARRRML_IRI = '~iri'
YARRRML_LANG = '~lang'

==> pretty_yarrrml2rml-0.6.1.dev1661763100.tar.gz: pretty_yarrrml2rml-0.6.1.dev1661763100/pretty_yarrrml2rml/constants.py <==



##############################################################################
#############################   RML CONSTANTS  ###############################
##############################################################################

RML_URI = 'http://semweb.mmlab.be/ns/rml#'
R2RML_URI = 'http://www.w3.org/ns/r2rml#'
RDF_URI = 'http://www.w3.org/1999/02/22-rdf-syntax-ns#'
D2RQ_URI = 'http://www.wiwiss.fu-berlin.de/suhl/bizer/D2RQ/0.1#'
QL_URI = 'http://semweb.mmlab.be/ns/ql#'
EXAMPLE_URI = 'http://example.com/ns#'
RDFS_URI = 'http://www.w3.org/2000/01/rdf-schema#'
XSD_URI = 'http://www.w3.org/2001/XMLSchema#'
RDF_TYPE = 'rdf:type'

RML_PREFIX = '@prefix'
RML_BASE = '@base'
RML_TRIPLES_MAP = 'rr:TriplesMap'
RML_LOGICAL_SOURCE_CLASS = 'rml:LogicalSource'
RML_LOGICAL_SOURCE = 'rml:logicalSource'
RML_SOURCE = 'rml:source'
RML_REFERENCE_FORMULATION = 'rml:referenceFormulation'
RML_ITERATOR = 'rml:iterator'
RML_REFERENCE = 'rml:reference'


R2RML_TEMPLATE = 'rr:template'
R2RML_CONSTANT = 'rr:constant'
R2RML_SUBJECT = 'rr:subjectMap'
R2RML_SUBJECT_CLASS = 'rr:SubjectMap'
R2RML_SQL_VERSION = 'rr:sqlVersion'
R2RML_SQL_QUERY = 'rr:sqlQuery'
R2RML_PREDICATE_OBJECT_MAP = 'rr:predicateObjectMap'
R2RML_PREDICATE_OBJECT_MAP_CLASS = 'rr:PredicateObjectMap'
R2RML_SHORTCUT_PREDICATE = 'rr:predicate'
R2RML_PREDICATE = 'rr:predicateMap'
R2RML_PREDICATE_CLASS = 'rr:PredicateMap'
R2RML_SHORTCUT_OBJECT = 'rr:object'
R2RML_OBJECT = 'rr:objectMap'
R2RML_OBJECT_CLASS = 'rr:ObjectMap'
R2RML_GRAPH = 'rr:graphMap'
R2RML_GRAPH_CLASS = 'rr:GraphMap'
R2RML_DATATYPE = 'rr:datatype'
R2RML_TERMTYPE = 'rr:termType'
R2RML_LANGUAGE = 'rr:language'
R2RML_IRI = 'rr:IRI'
R2RML_REFOBJECT_CLASS = 'rr:RefObjectMap'
R2RML_PARENT_TRIPLESMAP = 'rr:parentTriplesMap'
R2RML_JOIN_CONITION = 'rr:joinCondition'
R2RML_CHILD = 'rr:child'
R2RML_PARENT = 'rr:parent'

##############################################################################
#############################   D2RQ CONSTANTS  ###########################
##############################################################################
D2RQ_DATABASE_CLASS = 'd2rq:Database'
D2RQ_DSN = 'd2rq:jdbcDSN'
D2RQ_DRIVER = 'd2rq:jdbcDriver'
D2RQ_USER = 'd2rq:username'
D2RQ_PASS = 'd2rq:password'


##############################################################################
#############################   YARRRML CONSTANTS  ###########################
##############################################################################

YARRRML_PREFIXES = 'prefixes'
YARRRML_MAPPINGS = 'mappings'
YARRRML_SOURCES = 'sources'
YARRRML_SOURCE = 'source'
YARRRML_ACCESS = 'access'
YARRRML_QUERY = 'query'
YARRRML_REFERENCE_FORMULATION = 'referenceFormulation'
YARRRML_ITERATOR = 'iterator'
YARRRML_CREDENTIALS = 'credentials'
YARRRML_TYPE = 'type'
YARRRML_USERNAME = 'username'
YARRRML_PASSWORD = 'password'

YARRRML_SHORTCUT_SUBJECTS = 's'
YARRRML_SUBJECT = 'subject'
YARRRML_SUBJECTS = 'subjects'

YARRRML_GRAPHS = 'graphs'
YARRRML_GRAPH = 'graph'
YARRRML_SHORTCUT_GRAPH = 'g'

YARRRML_PREDICATEOBJECT = 'predicateobjects'
YARRRML_SHORTCUT_PREDICATEOBJECT = 'po'

YARRRML_PREDICATES = 'predicates'
YARRRML_SHORTCUT_PREDICATES = 'p'
YARRRML_OBJECT = 'objects'
YARRRML_SHORTCUT_OBJECT = 'o'
YARRRML_VALUE = 'value'
YARRRML_MAPPING = 'mapping'
YARRRML_DATATYPE = 'datatype'
YARRRML_LANGUAGE = 'language'

YARRRML_CONDITION = 'condition'
YARRRML_PARAMETERS = 'parameters'

YARRRML_IRI = '~iri'
YARRRML_LANG = '~lang'
